catalog

package
v0.0.24 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: AGPL-3.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var AttributeMap map[string]struct{}
var Attributes []string = []string{
	"id",
	"author",
	"title",
	"full_vendor_name",
	"availability",
}

Functions

func Init

func Init()

func IsAttr added in v0.0.16

func IsAttr(attr string) bool

func SetTable added in v0.0.16

func SetTable(setName string) string

return table containing set

Types

type Catalog

type Catalog struct {
	// contains filtered or unexported fields
}

func Initialize

func Initialize(program string, dp *pgxpool.Pool, security *config.Security) (*Catalog, error)

func (*Catalog) AllProjects added in v0.0.20

func (c *Catalog) AllProjects() []Project

func (*Catalog) AllRoles added in v0.0.20

func (c *Catalog) AllRoles() []Role

func (*Catalog) AllSets

func (c *Catalog) AllSets() []string

func (*Catalog) AllUsers added in v0.0.20

func (c *Catalog) AllUsers() []User

func (*Catalog) AlterProjectAddToProperty added in v0.0.24

func (c *Catalog) AlterProjectAddToProperty(project, property, value string) error

AlterProjectAddToProperty does not do synchronization and must not access the catalog cache

func (*Catalog) AlterProjectDropFromProperty added in v0.0.24

func (c *Catalog) AlterProjectDropFromProperty(project, property, value string) error

AlterProjectDropFromProperty does not do synchronization and must not access the catalog cache

func (*Catalog) AlterProjectSetProperty added in v0.0.24

func (c *Catalog) AlterProjectSetProperty(projectName, property, value string) error

AlterProjectSetProperty does not do synchronization and must not access the catalog cache

func (*Catalog) Authenticate added in v0.0.20

func (c *Catalog) Authenticate(username, password string) bool

func (*Catalog) CreateProject added in v0.0.23

func (c *Catalog) CreateProject(projectName string) error

func (*Catalog) CreateRole added in v0.0.20

func (c *Catalog) CreateRole(roleName string) error

func (*Catalog) CreateSet

func (c *Catalog) CreateSet(setName string) error

func (*Catalog) CreateUser added in v0.0.20

func (c *Catalog) CreateUser(userName, password string, superuser, login bool) error

func (*Catalog) DropSet added in v0.0.18

func (c *Catalog) DropSet(setName string) error

func (*Catalog) IsValidTargetProject added in v0.0.23

func (c *Catalog) IsValidTargetProject(projectName string) bool

func (*Catalog) IsValidTargetSet added in v0.0.20

func (c *Catalog) IsValidTargetSet(setName string) bool

func (*Catalog) ProjectExists added in v0.0.20

func (c *Catalog) ProjectExists(projectOrFullSetName string) bool

given a project name or fully qualified set name (project.set), return true if the project exists

func (*Catalog) ProjectProperties added in v0.0.20

func (c *Catalog) ProjectProperties(projectName string) ([][2]string, error)

func (*Catalog) RoleExists added in v0.0.20

func (c *Catalog) RoleExists(roleName string) bool

func (*Catalog) SetExists

func (c *Catalog) SetExists(setName string) bool

func (*Catalog) UserExists added in v0.0.20

func (c *Catalog) UserExists(userName string) bool

type Project added in v0.0.20

type Project struct {
	ProjectName string
}

type Role added in v0.0.20

type Role struct {
	RoleName  string
	UserNames []string
}

type User added in v0.0.20

type User struct {
	UserName  string
	Superuser bool
	Login     bool
}

Jump to