package
Version:
v0.0.19
Opens a new window with list of versions in this module.
Published: Feb 16, 2026
License: AGPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Request struct {
Commands string `json:"commands"`
}
client request to CCMS server
Source Files
¶
Click to show internal directories.
Click to hide internal directories.