Documentation
¶
Index ¶
- Variables
- func Init()
- func IsAttr(attr string) bool
- func SetTable(setName string) string
- type Catalog
- func (c *Catalog) AllProjects() []Project
- func (c *Catalog) AllRoles() []Role
- func (c *Catalog) AllSets() []string
- func (c *Catalog) AllUsers() []User
- func (c *Catalog) AlterProjectAddToProperty(project, property, value string) error
- func (c *Catalog) AlterProjectDropFromProperty(project, property, value string) error
- func (c *Catalog) AlterProjectSetProperty(projectName, property, value string) error
- func (c *Catalog) Authenticate(username, password string) bool
- func (c *Catalog) CreateProject(projectName string) error
- func (c *Catalog) CreateRole(roleName string) error
- func (c *Catalog) CreateSet(setName string) error
- func (c *Catalog) CreateUser(userName, password string, superuser, login bool) error
- func (c *Catalog) DropSet(setName string) error
- func (c *Catalog) IsValidTargetProject(projectName string) bool
- func (c *Catalog) IsValidTargetSet(setName string) bool
- func (c *Catalog) ProjectExists(projectOrFullSetName string) bool
- func (c *Catalog) ProjectProperties(projectName string) ([][2]string, error)
- func (c *Catalog) RoleExists(roleName string) bool
- func (c *Catalog) SetExists(setName string) bool
- func (c *Catalog) UserExists(userName string) bool
- type Project
- type Role
- type User
Constants ¶
This section is empty.
Variables ¶
var AttributeMap map[string]struct{}
var Attributes []string = []string{
"id",
"author",
"title",
"full_vendor_name",
"availability",
}
Functions ¶
Types ¶
type Catalog ¶
type Catalog struct {
// contains filtered or unexported fields
}
func Initialize ¶
func (*Catalog) AllProjects ¶ added in v0.0.20
func (*Catalog) AlterProjectAddToProperty ¶ added in v0.0.24
AlterProjectAddToProperty does not do synchronization and must not access the catalog cache
func (*Catalog) AlterProjectDropFromProperty ¶ added in v0.0.24
AlterProjectDropFromProperty does not do synchronization and must not access the catalog cache
func (*Catalog) AlterProjectSetProperty ¶ added in v0.0.24
AlterProjectSetProperty does not do synchronization and must not access the catalog cache
func (*Catalog) Authenticate ¶ added in v0.0.20
func (*Catalog) CreateProject ¶ added in v0.0.23
func (*Catalog) CreateRole ¶ added in v0.0.20
func (*Catalog) CreateUser ¶ added in v0.0.20
func (*Catalog) IsValidTargetProject ¶ added in v0.0.23
func (*Catalog) IsValidTargetSet ¶ added in v0.0.20
func (*Catalog) ProjectExists ¶ added in v0.0.20
given a project name or fully qualified set name (project.set), return true if the project exists
func (*Catalog) ProjectProperties ¶ added in v0.0.20
func (*Catalog) RoleExists ¶ added in v0.0.20
func (*Catalog) UserExists ¶ added in v0.0.20
Click to show internal directories.
Click to hide internal directories.